package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(`*``!````Z)D``#0`````U````@``!#0`(``)
M`"@`&P`:``$``'!$S@``1$X!`$1.`0`(````"`````0````$````!@```#0`
M```T@```-(```"`!```@`0``!0````0````#````5`$``%2!``!4@0``$P``
M`!,````$`````0````$``````````(````"```!0S@``4,X```4`````@```
M`0```.3.``#DS@$`Y,X!`(0"``"P$@``!@````"````"````\,X``/#.`0#P
MS@$`$`$``!`!```&````!`````0```!H`0``:($``&B!```@````(`````0`
M```$````4>5T9```````````````````````````!@````0```!2Y71DY,X`
M`.3.`0#DS@$`'`$``!P!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!`````!````1TY5```````"````!@```!````!A````>````!``````
M`````````&0`````````;````&H``````````````%0```!9````4````'``
M``!8````+`````````!#````=`````(````P````8P```!<````%````2@``
M````````````-@```%<```!>```````````````5````;P```%(```!,````
M`````'(```!U````<P```'<`````````*P````````!A`````````&(```!3
M```````````````*````(`````````!:```````````````Y````#@```&T`
M``!I```````````````9`````````%L``````````````$4`````````*```
M`$(```!&````8````#0````^```````````````(````(P```%4```!<````
M=@```%$```!)````/0```!$````````````````````\````70````````!E
M````:P```#\```!6````-P```'$`````````````````````````````````
M````````````````````````````````````````````````````````````
M``T``````````````````````````````!0`````````$P``````````````
M#``````````=```````````````&``````````,````>````&@``````````
M```````````````````````````````I````)P``````````````+P``````
M```!````&P```!(`````````,0`````````$````````````````````````
M```````````````````````E```````````````````````````````8````
M,@```#H````A````#P```$0`````````,P```#4`````````)````$T````J
M````'P````D````<```````````````N````(@```#@```!'````2```````
M``!!````+0``````````````7P`````````F````3@```#L```!+````0```
M`!8`````````:````&<```!F``````````````````````````<```!/````
M;@````L`````````````````````````"@$``$S1`0``````(``6`)D$```T
MHP``'````!(`#`"J!```Q*8``(`````2``P`$0```#26````````$@```&P#
M``!`E@```````!(````H````3)8````````2````>@,``%B6````````$@``
M`+<$```,[@``!````!(`#`"^`P``9)8````````2````#@$``.B9````````
M$@`,`#(```!PE@```````!(````+!```?)8````````2````/0```(B6````
M````$@```%```````````````"````!?```````````````@````<P```*"6
M````````$@```(<```"LE@```````!(```"9````N)8````````2````70,`
M`,26````````$@```,$$``"$\P```````!(`#0#'!```6.(``,0&```2``P`
MW00``,BJ``"8````$@`,`.L$``#XH0``/`$``!(`#`"F````T)8````````2
M````KP```-R6````````$@```+T```#HE@```````!(````!!0``1*<``-0!
M```2``P`#04``*#1``!@````$@`,`*,#``#TE@```````!(```#-`````)<`
M```````2````*`4``!3>``"0````$@`,`.0#```,EP```````!(````T!0``
M9-$!``0````1`!8`VP```!B7````````$@```(L%``#D]@``75<``!$`#@!#
M!0``E/,```0````1``X`Y@```"27````````$@```-0#```PEP```````!(`
M``#Z````/)<````````2````+0```$B7````````$@```!X#``!4EP``````
M`!(```#D`@``8)<````````2````_0,``&R7````````$@````@!``!,T0$`
M`````!``%@`5`0``>)<````````2````=P0``&C1`0``````$`#Q_R<!``"$
MEP```````!(````U`0``D)<````````2````10$``)R7````````$@```%8!
M``"HEP```````!(```!G`0``M)<````````2````G`,``,"7````````$@``
M`%@$``!,3@$``````!``\?]E`P``S)<````````2````MP,``-B7````````
M$@```!\%``#DEP```````!(```!2!0``F)H``%P````2``P`=@$``/"7````
M````$@```)$$``"4X0$``````!``\?]:!0``$.X``'0````2``P`A00``)3A
M`0``````$`#Q_Q\$``!HT0$`!````"$`%P#^`@``_)<````````2````A0$`
M``B8````````$@```*H#```4F````````!(```#X`@``()@````````2````
MDP$``"R8````````$@```%0#```XF````````!(```#&`P``1)@````````2
M````)P0``%"8````````$@```&L$``!HT0$``````!``\?^.`P``7)@`````
M```2````H0$``&B8````````$@```!8#``!TF````````!(````/`@``@)@`
M```````2````A@0``)3A`0``````$`#Q_Y4#``",F````````!(```"Q`P``
MF)@````````2````K0$``*28````````$@```+X!``"PF````````!(```#U
M`P``O)@````````2````+0,``,B8````````$@```&H%``#DX0``=````!(`
M#``>!```:-$!``0````A`!<`T`$``-28````````$@```.4!``#@F```````
M`!(```!?!```E.$!```````0`/'_AP,``.R8````````$@````,"``#XF```
M`````!(```#;`P``!)D````````2````%@(``!"9````````$@```!T$``!H
MT0$`!````!$`%P"&!0``8-$!``0````1`!8`,00``!R9````````$@```","
M```HF0```````!(```#K`P``-)D````````2````-0(``&S1`0`3````$0`7
M`)4%``!PU```)`@``!(`#`!D!```:-$!```````0`/'_3`,``$"9````````
M$@```$0"``!,F0```````!(```"B!0```-,``'`!```2``P`M`4``%"C``!T
M`P``$@`,`'(#``!8F0```````!(```!/`@``9)D````````2````7@(``'"9
M````````$@```$H$``!$3@$``````!``\?]P`@``?)D````````2````@`,`
M`(B9````````$@```(4"``"4F0```````!(````$!```H)D````````2````
M/P,``*R9````````$@````4#``"XF0```````!(```#!!0``&*D``+`!```2
M``P`1`,``,29````````$@```!@$``"HZ0``-`0``!(`#`!4!0``#)8`````
M```2``H`E@(``-"9````````$@```*T"``#<F0```````!(`````;&EB<&5R
M;"YS;RXU+C$P`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]F<F5E`'!E
M<FQ?<&%R<V4`4&5R;%]A=&9O<FM?=6YL;V-K`%]?9VUO;E]S=&%R=%]?`%]*
M=E]296=I<W1E<D-L87-S97,`4&5R;%])979A;%]R;V]T7W!T<@!097)L7TEI
M;E]E=F%L7W!T<@!097)L7TEO<%]P='(`<&5R;%]R=6X`4&5R;%]A=E]S:&EF
M=`!097)L7V=V7V9E=&-H<'8`4&5R;%]S=E]S971P=@!P97)L7V%L;&]C`%!E
M<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%]D;W5N=VEN9`!?7V1A=&%?<W1A<G0`
M4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S>7-?=&5R;0!B;V]T7T1Y;F%,;V%D
M97(`4&5R;%]A=&9O<FM?;&]C:P!097)L7VYE=UA37V9L86=S`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?879?9F5T8V@`<&5R;%]D97-T
M<G5C=`!097)L7VUG7W-E=`!097)L7TEP87)S97)?<'1R`%!E<FQ?27-T871B
M=69?<'1R`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?27!E<FQ?9&5S=')U
M8W1?;&5V96Q?<'1R`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7VYE=U-6<'8`
M4&5R;%])=&]P7V5N=E]P='(`4$Q?;65M;W)Y7W=R87``4&5R;%]N97=84P!0
M97)L7W-Y<U]I;FET,P!097)L7T=T:')?:V5Y7W!T<@!097)L7TEE>&ET7V9L
M86=S7W!T<@!097)L7TEC;VUP8W9?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R
M7W@`4&5R;%]S=E\R<'9?9FQA9W,`;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB
M<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T
M`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E
M9VES=&5R7V%T9F]R:P!E>&ET`'-P<FEN=&8`<W1R;F-M<`!C;&]S961I<@!S
M=')N8W!Y`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M
M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB
M8W)Y<'0N<V\N,0!?7V5X:61X7W-T87)T`%]?97AI9'A?96YD`%]E9&%T80!?
M7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`
M<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?24]?<W1D:6Y?
M=7-E9`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!84U]);G1E<FYA;'-?4$%2
M7T-,14%24U1!0TL`;F%M95]L;V%D7VUE7S(`<&%R7VUK=&UP9&ER`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?
M,BXT`````0`!``$````"`````@`!``(``0````(``````````````````@`!
M``$``0`!``````````$``0`"`````0`"``$````!``$````"`````@`#``,`
M`@`!`````0```````````````@`!``(``@`"``$````!``$``0`"``,````"
M``,````"``(``@`!``(````#``(``0`"``(```````(``@`!``(```````$`
M`@````(````"``$``@````(````!``$``@````$``0`"```````!`````@``
M``(``@`#``$``@`!``$```````$``0#4`@``$````"`````4:6D-```#`,X%
M`````````0`!`",#```0`````````!1I:0T```(`S@4```````!(T0$`%0X`
M`&C1`0`47```;-$!`!1A```,T`$`%@0``!#0`0`6!0``%-`!`!8&```8T`$`
M%@<``!S0`0`6"0``(-`!`!8+```DT`$`%@P``"C0`0`6#0``+-`!`!8.```P
MT`$`%A```#30`0`6$0``.-`!`!82```\T`$`%A,``$#0`0`6&```1-`!`!89
M``!(T`$`%AH``$S0`0`6'0``4-`!`!8>``!4T`$`%B```%C0`0`6(@``7-`!
M`!8E``!@T`$`%B8``&30`0`6)P``:-`!`!8H``!LT`$`%BD``'#0`0`6*@``
M=-`!`!8K``!XT`$`%BT``'S0`0`6+P``@-`!`!8P``"$T`$`%C$``(C0`0`6
M,@``C-`!`!8S``"0T`$`%C0``)30`0`6-@``F-`!`!8W``"<T`$`%C@``*#0
M`0`6.@``I-`!`!8_``"HT`$`%D```*S0`0`600``L-`!`!9"``"TT`$`%D,`
M`+C0`0`61```O-`!`!9%``#`T`$`%D8``,30`0`62```R-`!`!9)``#,T`$`
M%DH``-#0`0`62P``U-`!`!9-``#8T`$`%DX``-S0`0`63P``X-`!`!90``#D
MT`$`%E$``.C0`0`64@``[-`!`!95``#PT`$`%E8``/30`0`66```^-`!`!99
M``#\T`$`%EH```#1`0`66P``!-$!`!9>```(T0$`%E\```S1`0`68```$-$!
M`!9D```4T0$`%F4``!C1`0`6:```'-$!`!9I```@T0$`%FH``"31`0`6;```
M*-$!`!9M```LT0$`%FX``##1`0`6;P``--$!`!9P```XT0$`%G$``#S1`0`6
M<P``0-$!`!9V``!$T0$`%G<```3@+>4$T$WB`0$`ZP30C>(`@+WH!.`MY03@
MG^4.X(_@"/"^Y=`Y`0``QH_B$\J,XM#YO.4`QH_B$\J,XLCYO.4`QH_B$\J,
MXL#YO.4`QH_B$\J,XKCYO.4`QH_B$\J,XK#YO.4`QH_B$\J,XJCYO.4`QH_B
M$\J,XJ#YO.4`QH_B$\J,XICYO.4`QH_B$\J,XI#YO.4`QH_B$\J,XHCYO.4`
MQH_B$\J,XH#YO.4`QH_B$\J,XGCYO.4`QH_B$\J,XG#YO.4`QH_B$\J,XFCY
MO.4`QH_B$\J,XF#YO.4`QH_B$\J,XECYO.4`QH_B$\J,XE#YO.4`QH_B$\J,
MXDCYO.4`QH_B$\J,XD#YO.4`QH_B$\J,XCCYO.4`QH_B$\J,XC#YO.4`QH_B
M$\J,XBCYO.4`QH_B$\J,XB#YO.4`QH_B$\J,XACYO.4`QH_B$\J,XA#YO.4`
MQH_B$\J,X@CYO.4`QH_B$\J,X@#YO.4`QH_B$\J,XOCXO.4`QH_B$\J,XO#X
MO.4`QH_B$\J,XNCXO.4`QH_B$\J,XN#XO.4`QH_B$\J,XMCXO.4`QH_B$\J,
MXM#XO.4`QH_B$\J,XLCXO.4`QH_B$\J,XL#XO.4`QH_B$\J,XKCXO.4`QH_B
M$\J,XK#XO.4`QH_B$\J,XJCXO.4`QH_B$\J,XJ#XO.4`QH_B$\J,XICXO.4`
MQH_B$\J,XI#XO.4`QH_B$\J,XHCXO.4`QH_B$\J,XH#XO.4`QH_B$\J,XGCX
MO.4`QH_B$\J,XG#XO.4`QH_B$\J,XFCXO.4`QH_B$\J,XF#XO.4`QH_B$\J,
MXECXO.4`QH_B$\J,XE#XO.4`QH_B$\J,XDCXO.4`QH_B$\J,XD#XO.4`QH_B
M$\J,XCCXO.4`QH_B$\J,XC#XO.4`QH_B$\J,XBCXO.4`QH_B$\J,XB#XO.4`
MQH_B$\J,XACXO.4`QH_B$\J,XA#XO.4`QH_B$\J,X@CXO.4`QH_B$\J,X@#X
MO.4`QH_B$\J,XOCWO.4`QH_B$\J,XO#WO.4`QH_B$\J,XNCWO.4`QH_B$\J,
MXN#WO.4`QH_B$\J,XMCWO.4`QH_B$\J,XM#WO.4`QH_B$\J,XLCWO.4`QH_B
M$\J,XL#WO.4`QH_B$\J,XKCWO.4`QH_B$\J,XK#WO.4`QH_B$\J,XJCWO.4`
MQH_B$\J,XJ#WO.4`QH_B$\J,XICWO.4`QH_B$\J,XI#WO.4`QH_B$\J,XHCW
MO.4`QH_B$\J,XH#WO.4`QH_B$\J,XGCWO.4`QH_B$\J,XG#WO.4`QH_B$\J,
MXFCWO.4`QH_B$\J,XF#WO.4DP)_E`+"@XP00G>0-(*#A!"`MY00`+>40`)_E
M$#"?Y03`+>4:___K$/__ZPSN``"HZ0``$.X``!0PG^44()_E`S"/X`(0D^<`
M`%'C'O\O`17__^K0-0$`2`$``!`@G^4`,-+E``!3XP$P@P(`,,(%'O\OX7_1
M`0`H`)_E!.`MY0303>(`,)#E``!3XP,```H4,)_E``!3XP````HS_R_A!-"-
MX@"`O>CLS@$```````W`H.$`V"WI!+!,X@C03>(X,)_E$#`+Y0``H..M___K
M`#"@X0`PD^4#`*#A)?__ZP`PH.$#`*#A%!"?Y10@G^40,!OEFO__ZPS02^(`
MJ)WHF/,``*3S``"0EP``#<"@X0#8+>D$L$SB`=I-XA#03>(X,9_E#`!+X@,0
M@.<P,9_E#!!+X@,@@><!.DOB##!#X@0P0^(<`9_E`Q"@X1@AG^5Q___K`#"@
MX1`P"^40,!OE``!3XPL``-H0,!OE`2!#XO@PG^4,`$OB`S"`X`(P@^``,-/E
M``!3XP(``!H0,!OE`3!#XA`P"^40,!OE``!3XQT``-H0(!OE`3I+X@PP0^($
M,$/B`P"@X2\0H.-W___K`#"@X0``4^,3```*``"@XVS__^L`,*#A`#"3Y0,`
MH.'D_O_K`#"@X0,@H.$0P!OE:!"?Y0$Z2^(,,$/B!#!#X@(`H.$,($OB`1"2
MYP,@H.$,,*#A^_[_ZPX``.H``*#C6/__ZP`PH.$`,)/E`P"@X=#^_^L`,*#A
M(""?Y2#`G^4#`*#A##!+X@(0D^<,,$OB#""3YZ_^_^L,T$OB`*B=Z/3O___P
M[___P/,``/\/``#\[___#<"@X0#8+>D$L$SB(-!-XB@`"^40$`OE*"`;Y0``
M4N,#```*&#&?Y0`PD^4``%/C`@``&@`PH.,D,`OE/```ZB@@&^4<(`OE`@``
MZAPP&^4!,(/B'#`+Y1P@&^4`,-+E``!3XP,```H<(!OE`##2Y3T`4^/T__\:
M'#`;Y2@@&^4#,&+@(#`+Y;0PG^4`,)/E&#`+Y1X``.H@,!OE%``;Y2@0&^4#
M(*#A#?__ZP`PH.$``%/C$P``&B`P&^44(!OE`S""X``PT^4]`%/C#0``&A@@
M&^5H,)_E`#"3Y0(P8^!#,:#A`R"@X1`P&^4`((/E(#`;Y0$P@^(4(!OE`S""
MX"0P"^4*``#J&#`;Y00P@^(8,`OE&"`;Y0`@DN44(`OE%#`;Y0``4^/:__\:
M`""@XR0@"^4D,!OE`P"@X0S02^(`J)WH:-$!``W`H.$`V"WI!+!,XA#03>(8
M``OE$#!+XA@`&^4#$*#AI/__ZP`PH.$#`*#A#-!+X@"HG>@-P*#A$-@MZ02P
M3.(DT$WB(``+Y300"^4T$!OE`##1Y3T`4^,"```:-"`;Y0$@@N(T(`OE-``;
MY6K^_^L`,*#A&#`+Y1PP2^(@`!OE`Q"@X8O__^L`,*#A+#`+Y2PP&^4``%/C
M&@``"BP`&^5=_O_K`""@X1@P&^4#`%+A8```.C00&^4`,-'E+"`;Y0`PPN4L
M$!OE`##1Y0``4^,`,*`#`3"@$_\P`^(L(!OE`2""XBP@"^4T$!OE`1"!XC00
M"^4``%/C[?__&@`@H.,P(`OEJ0``ZK`RG^4`,)/E)#`+Y0`PH.,H,`OE!0``
MZB00&^4$$('B)!`+Y2@@&^4!((+B*"`+Y200&^4`,)'E``!3X_7__QIT,I_E
M`#"3Y0``4^,2```*8#*?Y0`@D^4H$!OE`C"!X@,QH.$"`*#A`Q"@X8[^_^L`
M,*#A`R"@X3@RG^4`((/E,#*?Y0`PD^4``%/C'0``&@`@X.,P(`OE@@``ZA@B
MG^4!,*#C`#""Y2@0&^4",('B`S&@X0,`H.%%_O_K`#"@X20P"^4D(!OE``!2
MXP(``!H`,.#C,#`+Y7(``.K4,9_E`""3Y2@P&^4#,:#A)``;Y0(0H.$#(*#A
M1/[_Z[0QG^4D$!OE`!"#Y:@QG^4`()/E*#`;Y0$P@^(#,:#A`R""X``PH.,`
M,(+E*#`;Y1PP"^4@(!OE+"`+Y0(``.HL,!OE`3"#XBPP"^4L$!OE`##1Y0``
M4^,#```*+"`;Y0`PTN4]`%/C]/__&D@QG^4`()/E'#`;Y0,QH.$#0(+@+"`;
MY2`P&^4",&/@`R"@X1@P&^4#,(+@`C"#X@,`H.$,_O_K`#"@X0`PA.4`,)3E
M``!3XP(``!H`,.#C,#`+Y3D``.KP,)_E`""3Y1PP&^4#,:#A`S""X``PD^4L
M,`OE`@``ZBP0&^4!$('B+!`+Y2`P&^4`,-/E+"`;Y0`PPN4L$!OE`##1Y0``
M4^,`,*`#`3"@$_\@`^(@,!OE`3"#XB`P"^4!,"+B_S`#X@``4^,#```:+"`;
MY0`PTN4]`%/CY___&CTPH.,L$!OE`##!Y2P@&^4!((+B+"`+Y300&^4`,-'E
M+"`;Y0`PPN4L$!OE`##1Y0``4^,`,*`#`3"@$_\P`^(L(!OE`2""XBP@"^4T
M$!OE`1"!XC00"^4``%/C[?__&@`@H.,P(`OE,#`;Y0,`H.$0T$OB$*B=Z&C1
M`0"`T0$`#<"@X0#8+>D$L$SB$-!-XA@`"^42``#J:#"?Y0`@D^40,!OE`S&@
MX0,@@N`<(`OE'"`;Y00P@N(`,)/E'"`;Y0`P@N4<(!OE`#"2Y0``4^,#```*
M'#`;Y00P@^(<,`OE\O__ZA`P2^(8`!OE`Q"@X9[^_^L`,*#A``!3X^7__QH,
MT$OB`*B=Z&C1`0`-P*#A`-@MZ02P3.("VDWB&-!-X@`PH.,4,`OEM/W_ZP`@
MH.$!.DOB##!#X@DP0^(#`*#A^!"?Y?@PG^7B_?_K`#"@X1`P"^40,!OE``!3
MXP,``*H`,*#C`BI+XB`P`N4N``#J`2I+X@P@0N()($+B`CI+X@PP0^(*,$/B
M`@"@X0,0H.$!*J#CG_W_ZP`PH.$0,`OE$#`;Y0``4^,#``"J`#"@XP(J2^(@
M,`+E&P``ZA`P&^4!,(/B`P"@X7']_^L`,*#A%#`+Y10P&^4``%/C`P``&@`P
MH.,"*DOB(#`"Y0X``.H0(!OE`CI+X@PP0^(*,$/B%``;Y0,0H.$W_?_K$"`;
MY10P&^4"((/@`#"@XP`PPN44,!OE`BI+XB`P`N4"*DOB(#`2Y0,`H.$,T$OB
M`*B=Z-CS``#D\P``#<"@X0#8+>D$L$SBK/__ZP`PH.$#`*#A`*B=Z`W`H.$`
MV"WI!+!,X@':3>(HT$WB-#.?Y0P@2^(#`(+G+#.?Y0P@2^(#$(+G)`.?Y8?^
M_^L`,*#A$#`+Y1@SG^4`()/E!#.?Y0P02^(#`)'G`A"@X1K]_^L`,*#A``!3
MXPH```KD,I_E\`*?Y0P@2^(#$)+G@_[_Z]`RG^4,$$OB`R"1YP$:2^(H(`'E
MJ@``ZK@RG^4,$$OB`P"1Y_/\_^L`,*#A&#`+Y;0RG^4`()/EG#*?Y0P02^(#
M`)'G`A"@X1W]_^L`,*#A'#`+Y8T``.H<,!OE`##3Y0``4^,!```:@#*?Y1PP
M"^40,!OE``!3XPT```H0`!OE'!`;Y5/]_^L`,*#A``!3XP<``!I0,I_E`#"3
MY0``H.,#$*#A!OW_ZP`PH.$<,`OE=@``ZAP`&^7._/_K`#"@X10P"^4'``#J
M%#`;Y0$P0^(4,`OE%"`;Y1PP&^4"((/@`#"@XP`PPN44,!OE`2!#XAPP&^4"
M,(/@`"#3Y>`QG^4`,)/E`##3Y0,`4N'M__\*%#`;Y0$@@^(8,!OE`R""X,PQ
MG^4#`%+A"@``VJ0QG^6P`9_E#"!+X@,0DN<S_O_KD#&?Y0P02^(#()'G`1I+
MXB@@`>5:``#JA#&?Y0#`D^4!*DOB#"!"XA`@0N)D,9_E#!!+X@,PD><`,(WE
M`@"@X7`1G^4<(!OE##"@X1K]_^L``*#C`_W_ZP`PH.$`,)/E`P"@X7O\_^L`
M,*#A`P"@X<S\_^L`(*#A`3I+X@PP0^(0,$/B`P"@X0(0H.$Z$@#K`#"@X0``
M4^,E```:``"@X_#\_^L`,*#A`#"3Y0,`H.%H_/_K`#"@X0,`H.&Y_/_K`#"@
MX1`PD^4/.@/B`@E3XQ<``!H!.DOB##!#XA`P0^(#`*#A`1"@XUW\_^L`,*#A
M``!3XPX``!H!.DOB##!#XA`P0^*<`)_E`Q"@X>_]_^L!.DOB##!#XA`P0^(#
M`*#AB_S_ZP`PH.$!*DOB*#`"Y1,``.IP,)_E`#"3Y0``H.,#$*#ACOS_ZP`P
MH.$<,`OE'#`;Y0``4^-N__\:-#"?Y4``G^4,($OB`Q"2Y]?]_^L@,)_E#!!+
MX@,@D><!&DOB*"`!Y0$:2^(H,!'E`P"@X0S02^(`J)WH[.___^CO___H\P``
M5-$!`/3S``!8T0$`!/0``/\/```(]```#<"@X0#8+>D$L$SB$-!-XA@`"^48
M,!OE%#`+Y1@P&^40,`OE#```ZA`P&^4`(-/E1#"?Y0`PD^4`,-/E`P!2X0(`
M`!H0,!OE`3"#XA0P"^40,!OE`3"#XA`P"^40,!OE`##3Y0``4^/N__\:%#`;
MY0,`H.$,T$OB`*B=Z%31`0`-P*#A`-@MZ02P3.(0T$WB$``+Y1`P&^4``%/C
M`P``"A`P&^4`,-/E``!3XP0``!J0`9_E-_S_ZP`PH.$8,`OE7```ZA``&^4+
M_/_K`#"@X0$@0^(0,!OE`C"#X!0P"^4"``#J%"`;Y0$@0N(4(`OE$#`;Y10@
M&^4#`%+A"@``FA0P&^4`(-/E/#&?Y0`PD^4`,-/E`P!2X?'__PH"``#J%"`;
MY0$@0N(4(`OE$#`;Y10@&^4#`%+A!@``FA0P&^4`(-/E`#&?Y0`PD^4`,-/E
M`P!2X?'__QH0,!OE%"`;Y0,`4N$2```:%#`;Y0`@T^74,)_E`#"3Y0`PT^4#
M`%+A!```&KP`G^4"_/_K`#"@X1@P"^4G``#JK#"?Y0`PD^4#`*#A^_O_ZP`P
MH.$8,`OE(```ZA0@&^4!($+B%"`+Y1`P&^44(!OE`P!2X08``)H4,!OE`"#3
MY6PPG^4`,)/E`##3Y0,`4N'Q__\*%"`;Y1`P&^4",&/@`C"#X@$*4^,"``":
M`""@XQ@@"^4)``#J%"`;Y1`P&^4",&/@`3"#XB@`G^40$!OE`R"@X7/[_^L8
M,)_E&#`+Y1@P&^4#`*#A#-!+X@"HG>@$]```5-$!`(31`0`-P*#A`-@MZ02P
M3.(HT$WB5#&?Y3(@2^(BP*#C`@"@X0,0H.$,(*#AI/O_ZSP!G^4'_O_K.`&?
MY07^_^LT`9_E`_[_ZS`!G^4!_O_K+`&?Y?_]_^LH`9_E_?W_ZR0!G^7[_?_K
M(`&?Y?G]_^L<`9_E]_W_ZQ@!G^4#_?_K`#"@X1`P"^40,!OE``!3XP(```KH
M`)_E$!`;Y0C]_^OT`)_E^?S_ZP`PH.$0,`OE$#`;Y0``4^,"```*W`"?Y1`0
M&^7^_/_KU`"?Y>_\_^L`,*#A$#`+Y1`P&^4``%/C`P``"I``G^40$!OE]/S_
MZQD``.JL`)_EY/S_ZP`PH.$0,`OE$#`;Y0``4^,#```*:`"?Y1`0&^7I_/_K
M#@``ZC(P2^(1,(/B$#`+Y1``&^5T$)_E"B"@X[O[_^L`,*#A``!3XP0``!H0
M,!OE"C"#XB@`G^4#$*#AV?S_ZQ``G^5($)_EUOS_ZPS02^(`J)WHT/0``!#T
M```@]```Z/,``"ST```X]```1/0``/3S``!0]```7/0``&CT``!\]```D/0`
M`)ST``"L]```P/0``,ST```-P*#A`-@MZ02P3.(0T$WB>#"?Y0`PD^4!`'/C
M%@``&FP`G^6L_/_K`#"@X1`P"^40,!OE``!3XPH```H0,!OE`##3Y0``4^,&
M```*$#`;Y0`PT^4P`%/C`@``"@$@H.,8(`OE`0``Z@`PH.,8,`OE&#"?Y1@@
M&^4`((/E##"?Y0`PD^4#`*#A#-!+X@"HG>A<T0$`+/0```W`H.$`V"WI!+!,
MXA?>3>)X`0OE>#$;Y1PP@^(L,`OE`#"@XS`P"^4<``#J+#`;Y0`PD^4H,`OE
M+#`;Y00P@^(L,`OE,``;Y2@P&^4#+*#A*#`;Y0,TH.'_.`/B`R""X2@P&^4C
M-*#A_SP#X@,@@N$H,!OE(SR@X0,0@N$T()_E`#&@X0P`2^(#,(#@`C"#X``0
M@^4P,!OE`3"#XC`P"^4P,!OE#P!3X]___]H0,*#C,#`+Y3X``.J<_O__F7F"
M6J'KV6XP`!OE,#`;Y0,P0^(@(!_E`S&@X0P02^(#,('@`C"#X``0D^4P,!OE
M"#!#XD`@'^4#,:#A#,!+X@,PC.`",(/@`#"3Y0,0(>`P,!OE#C!#XF0@'^4#
M,:#A#,!+X@,PC.`",(/@`#"3Y0,0(>`P,!OE$#!#XH@@'^4#,:#A#,!+X@,P
MC.`",(/@`#"3Y0,0(>"D(!_E`#&@X0P`2^(#,(#@`C"#X``0@^4P`!OE,#`;
MY<0@'^4#,:#A#!!+X@,P@>`",(/@`#"3Y>,?H.'@(!_E`#&@X0S`2^(#,(S@
M`C"#X``0@^4P,!OE`3"#XC`P"^4P,!OE3P!3X\#__]IX,1OE`#"3Y20P"^5X
M,1OE!#"3Y2`P"^5X,1OE"#"3Y1PP"^5X,1OE##"3Y1@P"^5X,1OE$#"3Y10P
M"^47/DOB$#`+Y20P&^7C#:#A("`;Y1PP&^4#$`+@(#`;Y0,@X.$8,!OE`S`"
MX`,P@>$#((#@%#`;Y0,@@N`0,!OE`#"3Y0,@@N"0,1_E`S""X"@P"^40,!OE
M!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@X20@&^4@,!OE`Q`"X"0P&^4#
M(.#A'#`;Y0,P`N`#,('A`R"`X!@P&^4#((+@$#`;Y0`PD^4#((+@]#$?Y0,P
M@N`4,`OE$#`;Y00P@^(0,`OE)#`;Y6,QH.$D,`OE%#`;Y>,-H.$H(!OE)#`;
MY0,0`N`H,!OE`R#@X2`P&^4#,`+@`S"!X0,@@.`<,!OE`R""X!`P&^4`,)/E
M`R""X%@R'^4#,(+@&#`+Y1`P&^4$,(/B$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C
M#:#A%"`;Y2@P&^4#$`+@%#`;Y0,@X.$D,!OE`S`"X`,P@>$#((#@(#`;Y0,@
M@N`0,!OE`#"3Y0,@@N"\,A_E`S""X!PP"^40,!OE!#"#XA`P"^44,!OE8S&@
MX10P"^4<,!OEXPV@X1@@&^44,!OE`Q`"X!@P&^4#(.#A*#`;Y0,P`N`#,('A
M`R"`X"0P&^4#((+@$#`;Y0`PD^4#((+@(#,?Y0,P@N`@,`OE$#`;Y00P@^(0
M,`OE&#`;Y6,QH.$8,`OE(#`;Y>,-H.$<(!OE&#`;Y0,0`N`<,!OE`R#@X10P
M&^4#,`+@`S"!X0,@@.`H,!OE`R""X!`P&^4`,)/E`R""X(0S'^4#,(+@)#`+
MY1`P&^4$,(/B$#`+Y1PP&^5C,:#A'#`+Y20P&^7C#:#A("`;Y1PP&^4#$`+@
M(#`;Y0,@X.$8,!OE`S`"X`,P@>$#((#@%#`;Y0,@@N`0,!OE`#"3Y0,@@N#H
M,Q_E`S""X"@P"^40,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@X20@
M&^4@,!OE`Q`"X"0P&^4#(.#A'#`;Y0,P`N`#,('A`R"`X!@P&^4#((+@$#`;
MY0`PD^4#((+@3#0?Y0,P@N`4,`OE$#`;Y00P@^(0,`OE)#`;Y6,QH.$D,`OE
M%#`;Y>,-H.$H(!OE)#`;Y0,0`N`H,!OE`R#@X2`P&^4#,`+@`S"!X0,@@.`<
M,!OE`R""X!`P&^4`,)/E`R""X+`T'^4#,(+@&#`+Y1`P&^4$,(/B$#`+Y2@P
M&^5C,:#A*#`+Y1@P&^7C#:#A%"`;Y2@P&^4#$`+@%#`;Y0,@X.$D,!OE`S`"
MX`,P@>$#((#@(#`;Y0,@@N`0,!OE`#"3Y0,@@N`4-1_E`S""X!PP"^40,!OE
M!#"#XA`P"^44,!OE8S&@X10P"^4<,!OEXPV@X1@@&^44,!OE`Q`"X!@P&^4#
M(.#A*#`;Y0,P`N`#,('A`R"`X"0P&^4#((+@$#`;Y0`PD^4#((+@>#4?Y0,P
M@N`@,`OE$#`;Y00P@^(0,`OE&#`;Y6,QH.$8,`OE(#`;Y>,-H.$<(!OE&#`;
MY0,0`N`<,!OE`R#@X10P&^4#,`+@`S"!X0,@@.`H,!OE`R""X!`P&^4`,)/E
M`R""X-PU'^4#,(+@)#`+Y1`P&^4$,(/B$#`+Y1PP&^5C,:#A'#`+Y20P&^7C
M#:#A("`;Y1PP&^4#$`+@(#`;Y0,@X.$8,!OE`S`"X`,P@>$#((#@%#`;Y0,@
M@N`0,!OE`#"3Y0,@@N!`-A_E`S""X"@P"^40,!OE!#"#XA`P"^4@,!OE8S&@
MX2`P"^4H,!OEXPV@X20@&^4@,!OE`Q`"X"0P&^4#(.#A'#`;Y0,P`N`#,('A
M`R"`X!@P&^4#((+@$#`;Y0`PD^4#((+@I#8?Y0,P@N`4,`OE$#`;Y00P@^(0
M,`OE)#`;Y6,QH.$D,`OE%#`;Y>,-H.$H(!OE)#`;Y0,0`N`H,!OE`R#@X2`P
M&^4#,`+@`S"!X0,@@.`<,!OE`R""X!`P&^4`,)/E`R""X`@W'^4#,(+@&#`+
MY1`P&^4$,(/B$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C#:#A%"`;Y2@P&^4#$`+@
M%#`;Y0,@X.$D,!OE`S`"X`,P@>$#((#@(#`;Y0,@@N`0,!OE`#"3Y0,@@N!L
M-Q_E`S""X!PP"^40,!OE!#"#XA`P"^44,!OE8S&@X10P"^4<,!OEXPV@X1@@
M&^44,!OE`Q`"X!@P&^4#(.#A*#`;Y0,P`N`#,('A`R"`X"0P&^4#((+@$#`;
MY0`PD^4#((+@T#<?Y0,P@N`@,`OE$#`;Y00P@^(0,`OE&#`;Y6,QH.$8,`OE
M(#`;Y>,-H.$<(!OE&#`;Y0,0`N`<,!OE`R#@X10P&^4#,`+@`S"!X0,@@.`H
M,!OE`R""X!`P&^4`,)/E`R""X#0X'^4#,(+@)#`+Y1`P&^4$,(/B$#`+Y1PP
M&^5C,:#A'#`+Y20P&^7C#:#A("`;Y1PP&^4#$`+@(#`;Y0,@X.$8,!OE`S`"
MX`,P@>$#((#@%#`;Y0,@@N`0,!OE`#"3Y0,@@N"8.!_E`S""X"@P"^40,!OE
M!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@X20@&^4@,!OE`Q`"X"0P&^4#
M(.#A'#`;Y0,P`N`#,('A`R"`X!@P&^4#((+@$#`;Y0`PD^4#((+@_#@?Y0,P
M@N`4,`OE$#`;Y00P@^(0,`OE)#`;Y6,QH.$D,`OE%#`;Y>,=H.$H(!OE)#`;
MY0,@(N`@,!OE`S`BX`,@@>`<,!OE`R""X!`P&^4`,)/E`R""X%`Y'^4#,(+@
M&#`+Y1`P&^4$,(/B$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C':#A%"`;Y2@P&^4#
M("+@)#`;Y0,P(N`#(('@(#`;Y0,@@N`0,!OE`#"3Y0,@@N"H.1_E`S""X!PP
M"^40,!OE!#"#XA`P"^44,!OE8S&@X10P"^4<,!OEXQV@X1@@&^44,!OE`R`B
MX"@P&^4#,"+@`R"!X"0P&^4#((+@$#`;Y0`PD^4#((+@`#H?Y0,P@N`@,`OE
M$#`;Y00P@^(0,`OE&#`;Y6,QH.$8,`OE(#`;Y>,=H.$<(!OE&#`;Y0,@(N`4
M,!OE`S`BX`,@@>`H,!OE`R""X!`P&^4`,)/E`R""X%@Z'^4#,(+@)#`+Y1`P
M&^4$,(/B$#`+Y1PP&^5C,:#A'#`+Y20P&^7C':#A("`;Y1PP&^4#("+@&#`;
MY0,P(N`#(('@%#`;Y0,@@N`0,!OE`#"3Y0,@@N"P.A_E`S""X"@P"^40,!OE
M!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXQV@X20@&^4@,!OE`R`BX!PP&^4#
M,"+@`R"!X!@P&^4#((+@$#`;Y0`PD^4#((+@"#L?Y0,P@N`4,`OE$#`;Y00P
M@^(0,`OE)#`;Y6,QH.$D,`OE%#`;Y>,=H.$H(!OE)#`;Y0,@(N`@,!OE`S`B
MX`,@@>`<,!OE`R""X!`P&^4`,)/E`R""X&`['^4#,(+@&#`+Y1`P&^4$,(/B
M$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C':#A%"`;Y2@P&^4#("+@)#`;Y0,P(N`#
M(('@(#`;Y0,@@N`0,!OE`#"3Y0,@@N"X.Q_E`S""X!PP"^40,!OE!#"#XA`P
M"^44,!OE8S&@X10P"^4<,!OEXQV@X1@@&^44,!OE`R`BX"@P&^4#,"+@`R"!
MX"0P&^4#((+@$#`;Y0`PD^4#((+@$#P?Y0,P@N`@,`OE$#`;Y00P@^(0,`OE
M&#`;Y6,QH.$8,`OE(#`;Y>,=H.$<(!OE&#`;Y0,@(N`4,!OE`S`BX`,@@>`H
M,!OE`R""X!`P&^4`,)/E`R""X&@\'^4#,(+@)#`+Y1`P&^4$,(/B$#`+Y1PP
M&^5C,:#A'#`+Y20P&^7C':#A("`;Y1PP&^4#("+@&#`;Y0,P(N`#(('@%#`;
MY0,@@N`0,!OE`#"3Y0,@@N#`/!_E`S""X"@P"^40,!OE!#"#XA`P"^4@,!OE
M8S&@X2`P"^4H,!OEXQV@X20@&^4@,!OE`R`BX!PP&^4#,"+@`R"!X!@P&^4#
M((+@$#`;Y0`PD^4#((+@&#T?Y0,P@N`4,`OE$#`;Y00P@^(0,`OE)#`;Y6,Q
MH.$D,`OE%#`;Y>,=H.$H(!OE)#`;Y0,@(N`@,!OE`S`BX`,@@>`<,!OE`R""
MX!`P&^4`,)/E`R""X'`]'^4#,(+@&#`+Y1`P&^4$,(/B$#`+Y2@P&^5C,:#A
M*#`+Y1@P&^7C':#A%"`;Y2@P&^4#("+@)#`;Y0,P(N`#(('@(#`;Y0,@@N`0
M,!OE`#"3Y0,@@N#(/1_E`S""X!PP"^40,!OE!#"#XA`P"^44,!OE8S&@X10P
M"^4<,!OEXQV@X1@@&^44,!OE`R`BX"@P&^4#,"+@`R"!X"0P&^4#((+@$#`;
MY0`PD^4#((+@(#X?Y0,P@N`@,`OE$#`;Y00P@^(0,`OE&#`;Y6,QH.$8,`OE
M(#`;Y>,=H.$<(!OE&#`;Y0,@(N`4,!OE`S`BX`,@@>`H,!OE`R""X!`P&^4`
M,)/E`R""X'@^'^4#,(+@)#`+Y1`P&^4$,(/B$#`+Y1PP&^5C,:#A'#`+Y20P
M&^7C':#A("`;Y1PP&^4#("+@&#`;Y0,P(N`#(('@%#`;Y0,@@N`0,!OE`#"3
MY0,@@N#0/A_E`S""X"@P"^40,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OE
MXQV@X20@&^4@,!OE`R`BX!PP&^4#,"+@`R"!X!@P&^4#((+@$#`;Y0`PD^4#
M((+@*#\?Y0,P@N`4,`OE$#`;Y00P@^(0,`OE)#`;Y6,QH.$D,`OE%#`;Y>,=
MH.$H(!OE)#`;Y0,@(N`@,!OE`S`BX`,@@>`<,!OE`R""X!`P&^4`,)/E`R""
MX(`_'^4#,(+@&#`+Y1`P&^4$,(/B$#`+Y2@P&^5C,:#A*#`+Y1@P&^7C':#A
M%"`;Y2@P&^4#("+@)#`;Y0,P(N`#(('@(#`;Y0,@@N`0,!OE`#"3Y0,@@N#8
M/Q_E`S""X!PP"^40,!OE!#"#XA`P"^44,!OE8S&@X10P"^4<,!OEXPV@X10@
M&^4H,!OE`R""X1@P&^4#$`+@%"`;Y2@P&^4#,`+@`S"!X0,@@.`D,!OE`R""
MX!`P&^4`,)/E`R""X#0_G^4#,(+@(#`+Y1`P&^4$,(/B$#`+Y1@P&^5C,:#A
M&#`+Y2`P&^7C#:#A&"`;Y10P&^4#((+A'#`;Y0,0`N`8(!OE%#`;Y0,P`N`#
M,('A`R"`X"@P&^4#((+@$#`;Y0`PD^4#((+@S#Z?Y0,P@N`D,`OE$#`;Y00P
M@^(0,`OE'#`;Y6,QH.$<,`OE)#`;Y>,-H.$<(!OE&#`;Y0,@@N$@,!OE`Q`"
MX!P@&^48,!OE`S`"X`,P@>$#((#@%#`;Y0,@@N`0,!OE`#"3Y0,@@N!D/I_E
M`S""X"@P"^40,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@X2`@&^4<
M,!OE`R""X20P&^4#$`+@("`;Y1PP&^4#,`+@`S"!X0,@@.`8,!OE`R""X!`P
M&^4`,)/E`R""X/P]G^4#,(+@%#`+Y1`P&^4$,(/B$#`+Y20P&^5C,:#A)#`+
MY10P&^7C#:#A)"`;Y2`P&^4#((+A*#`;Y0,0`N`D(!OE(#`;Y0,P`N`#,('A
M`R"`X!PP&^4#((+@$#`;Y0`PD^4#((+@E#V?Y0,P@N`8,`OE$#`;Y00P@^(0
M,`OE*#`;Y6,QH.$H,`OE&#`;Y>,-H.$H(!OE)#`;Y0,@@N$4,!OE`Q`"X"@@
M&^4D,!OE`S`"X`,P@>$#((#@(#`;Y0,@@N`0,!OE`#"3Y0,@@N`L/9_E`S""
MX!PP"^40,!OE!#"#XA`P"^44,!OE8S&@X10P"^4<,!OEXPV@X10@&^4H,!OE
M`R""X1@P&^4#$`+@%"`;Y2@P&^4#,`+@`S"!X0,@@.`D,!OE`R""X!`P&^4`
M,)/E`R""X,0\G^4#,(+@(#`+Y1`P&^4$,(/B$#`+Y1@P&^5C,:#A&#`+Y2`P
M&^7C#:#A&"`;Y10P&^4#((+A'#`;Y0,0`N`8(!OE%#`;Y0,P`N`#,('A`R"`
MX"@P&^4#((+@$#`;Y0`PD^4#((+@7#R?Y0,P@N`D,`OE$#`;Y00P@^(0,`OE
M'#`;Y6,QH.$<,`OE)#`;Y>,-H.$<(!OE&#`;Y0,@@N$@,!OE`Q`"X!P@&^48
M,!OE`S`"X`,P@>$#((#@%#`;Y0,@@N`0,!OE`#"3Y0,@@N#T.Y_E`S""X"@P
M"^40,!OE!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@X2`@&^4<,!OE`R""
MX20P&^4#$`+@("`;Y1PP&^4#,`+@`S"!X0,@@.`8,!OE`R""X!`P&^4`,)/E
M`R""X(P[G^4#,(+@%#`+Y1`P&^4$,(/B$#`+Y20P&^5C,:#A)#`+Y10P&^7C
M#:#A)"`;Y2`P&^4#((+A*#`;Y0,0`N`D(!OE(#`;Y0,P`N`#,('A`R"`X!PP
M&^4#((+@$#`;Y0`PD^4#((+@)#N?Y0,P@N`8,`OE$#`;Y00P@^(0,`OE*#`;
MY6,QH.$H,`OE&#`;Y>,-H.$H(!OE)#`;Y0,@@N$4,!OE`Q`"X"@@&^4D,!OE
M`S`"X`,P@>$#((#@(#`;Y0,@@N`0,!OE`#"3Y0,@@N"\.I_E`S""X!PP"^40
M,!OE!#"#XA`P"^44,!OE8S&@X10P"^4<,!OEXPV@X10@&^4H,!OE`R""X1@P
M&^4#$`+@%"`;Y2@P&^4#,`+@`S"!X0,@@.`D,!OE`R""X!`P&^4`,)/E`R""
MX%0ZG^4#,(+@(#`+Y1`P&^4$,(/B$#`+Y1@P&^5C,:#A&#`+Y2`P&^7C#:#A
M&"`;Y10P&^4#((+A'#`;Y0,0`N`8(!OE%#`;Y0,P`N`#,('A`R"`X"@P&^4#
M((+@$#`;Y0`PD^4#((+@[#F?Y0,P@N`D,`OE$#`;Y00P@^(0,`OE'#`;Y6,Q
MH.$<,`OE)#`;Y>,-H.$<(!OE&#`;Y0,@@N$@,!OE`Q`"X!P@&^48,!OE`S`"
MX`,P@>$#((#@%#`;Y0,@@N`0,!OE`#"3Y0,@@N"$.9_E`S""X"@P"^40,!OE
M!#"#XA`P"^4@,!OE8S&@X2`P"^4H,!OEXPV@X2`@&^4<,!OE`R""X20P&^4#
M$`+@("`;Y1PP&^4#,`+@`S"!X0,@@.`8,!OE`R""X!`P&^4`,)/E`R""X!PY
MG^4#,(+@%#`+Y1`P&^4$,(/B$#`+Y20P&^5C,:#A)#`+Y10P&^7C#:#A)"`;
MY2`P&^4#((+A*#`;Y0,0`N`D(!OE(#`;Y0,P`N`#,('A`R"`X!PP&^4#((+@
M$#`;Y0`PD^4#((+@M#B?Y0,P@N`8,`OE$#`;Y00P@^(0,`OE*#`;Y6,QH.$H
M,`OE&#`;Y>,-H.$H(!OE)#`;Y0,@@N$4,!OE`Q`"X"@@&^4D,!OE`S`"X`,P
M@>$#((#@(#`;Y0,@@N`0,!OE`#"3Y0,@@N!,.)_E`S""X!PP"^40,!OE!#"#
MXA`P"^44,!OE8S&@X10P"^4<,!OEXPV@X10@&^4H,!OE`R""X1@P&^4#$`+@
M%"`;Y2@P&^4#,`+@`S"!X0,@@.`D,!OE`R""X!`P&^4`,)/E`R""X.0WG^4#
M,(+@(#`+Y1`P&^4$,(/B$#`+Y1@P&^5C,:#A&#`+Y2`P&^7C#:#A&"`;Y10P
M&^4#((+A'#`;Y0,0`N`8(!OE%#`;Y0,P`N`#,('A`R"`X"@P&^4#((+@$#`;
MY0`PD^4#((+@?#>?Y0,P@N`D,`OE$#`;Y00P@^(0,`OE'#`;Y6,QH.$<,`OE
M)#`;Y>,=H.$@(!OE'#`;Y0,@(N`8,!OE`S`BX`,@@>`4,!OE`R""X!`P&^4`
M,)/E`R""X"@WG^4#,(+@*#`+Y1`P&^4$,(/B$#`+Y2`P&^5C,:#A(#`+Y2@P
M&^7C':#A)"`;Y2`P&^4#("+@'#`;Y0,P(N`#(('@&#`;Y0,@@N`0,!OE`#"3
MY0,@@N#0-I_E`S""X!0P"^40,!OE!#"#XA`P"^4D,!OE8S&@X20P"^44,!OE
MXQV@X2@@&^4D,!OE`R`BX"`P&^4#,"+@`R"!X!PP&^4#((+@$#`;Y0`PD^4#
M((+@>#:?Y0,P@N`8,`OE$#`;Y00P@^(0,`OE*#`;Y6,QH.$H,`OE&#`;Y>,=
MH.$4(!OE*#`;Y0,@(N`D,!OE`S`BX`,@@>`@,!OE`R""X!`P&^4`,)/E`R""
MX"`VG^4#,(+@'#`+Y1`P&^4$,(/B$#`+Y10P&^5C,:#A%#`+Y1PP&^7C':#A
M&"`;Y10P&^4#("+@*#`;Y0,P(N`#(('@)#`;Y0,@@N`0,!OE`#"3Y0,@@N#(
M-9_E`S""X"`P"^40,!OE!#"#XA`P"^48,!OE8S&@X1@P"^4@,!OEXQV@X1P@
M&^48,!OE`R`BX!0P&^4#,"+@`R"!X"@P&^4#((+@$#`;Y0`PD^4#((+@<#6?
MY0,P@N`D,`OE$#`;Y00P@^(0,`OE'#`;Y6,QH.$<,`OE)#`;Y>,=H.$@(!OE
M'#`;Y0,@(N`8,!OE`S`BX`,@@>`4,!OE`R""X!`P&^4`,)/E`R""X!@UG^4#
M,(+@*#`+Y1`P&^4$,(/B$#`+Y2`P&^5C,:#A(#`+Y2@P&^7C':#A)"`;Y2`P
M&^4#("+@'#`;Y0,P(N`#(('@&#`;Y0,@@N`0,!OE`#"3Y0,@@N#`-)_E`S""
MX!0P"^40,!OE!#"#XA`P"^4D,!OE8S&@X20P"^44,!OEXQV@X2@@&^4D,!OE
M`R`BX"`P&^4#,"+@`R"!X!PP&^4#((+@$#`;Y0`PD^4#((+@:#2?Y0,P@N`8
M,`OE$#`;Y00P@^(0,`OE*#`;Y6,QH.$H,`OE&#`;Y>,=H.$4(!OE*#`;Y0,@
M(N`D,!OE`S`BX`,@@>`@,!OE`R""X!`P&^4`,)/E`R""X!`TG^4#,(+@'#`+
MY1`P&^4$,(/B$#`+Y10P&^5C,:#A%#`+Y1PP&^7C':#A&"`;Y10P&^4#("+@
M*#`;Y0,P(N`#(('@)#`;Y0,@@N`0,!OE`#"3Y0,@@N"X,Y_E`S""X"`P"^40
M,!OE!#"#XA`P"^48,!OE8S&@X1@P"^4@,!OEXQV@X1P@&^48,!OE`R`BX!0P
M&^4#,"+@`R"!X"@P&^4#((+@$#`;Y0`PD^4#((+@8#.?Y0,P@N`D,`OE$#`;
MY00P@^(0,`OE'#`;Y6,QH.$<,`OE)#`;Y>,=H.$@(!OE'#`;Y0,@(N`8,!OE
M`S`BX`,@@>`4,!OE`R""X!`P&^4`,)/E`R""X`@SG^4#,(+@*#`+Y1`P&^4$
M,(/B$#`+Y2`P&^5C,:#A(#`+Y2@P&^7C':#A)"`;Y2`P&^4#("+@'#`;Y0,P
M(N`#(('@&#`;Y0,@@N`0,!OE`#"3Y0,@@N"P,I_E`S""X!0P"^40,!OE!#"#
MXA`P"^4D,!OE8S&@X20P"^44,!OEXQV@X2@@&^4D,!OE`R`BX"`P&^4#,"+@
M`R"!X!PP&^4#((+@$#`;Y0`PD^4#((+@6#*?Y0,P@N`8,`OE$#`;Y00P@^(0
M,`OE*#`;Y6,QH.$H,`OE&#`;Y>,=H.$4(!OE*#`;Y0,@(N`D,!OE`S`BX`,@
M@>`@,!OE`R""X!`P&^4`,)/E`R""X``RG^4#,(+@'#`+Y1`P&^4$,(/B$#`+
MY10P&^5C,:#A%#`+Y1PP&^7C':#A&"`;Y10P&^4#("+@*#`;Y0,P(N`#(('@
M)#`;Y0,@@N`0,!OE`#"3Y0,@@N"H,9_E`S""X"`P"^40,!OE!#"#XA`P"^48
M,!OE8S&@X1@P"^4@,!OEXQV@X1P@&^48,!OE`R`BX!0P&^4#,"+@`R"!X"@P
M&^4#((+@$#`;Y0`PD^4#((+@4#&?Y0,P@N`D,`OE$#`;Y00P@^(0,`OE'#`;
MY6,QH.$<,`OE)#`;Y>,=H.$@(!OE'#`;Y0,@(N`8,!OE`S`BX`,@@>`4,!OE
M`R""X!`P&^4`,)/E`R""X/@PG^4#,(+@*#`+Y1`P&^4$,(/B$#`+Y2`P&^5C
M,:#A(#`+Y2@P&^7C':#A)"`;Y2`P&^4#("+@'#`;Y0,P(N`#(('@&#`;Y0,@
M@N`0,!OE`#"3Y0,@@N"@,)_E`S""X!0P"^40,!OE!#"#XA`P"^4D,!OE8S&@
MX20P"^5X,1OE`""3Y10P&^4#((+@>#$;Y0`@@^5X,1OE!""3Y2@P&^4#((+@
M>#$;Y00@@^5X,1OE"""3Y20P&^4#((+@>#$;Y0@@@^5X,1OE#""3Y2`P&^4#
M((+@>#$;Y0P@@^5X,1OE$""3Y1PP&^4#((+@>#$;Y1`@@^4,T$OB`*B=Z-R\
M&X_6P6+*#<"@X0#8+>D$L$SB"-!-XA``"^40(!OE7#"?Y0`P@N40(!OE5#"?
MY00P@N40(!OE3#"?Y0@P@N40(!OE1#"?Y0PP@N40(!OE/#"?Y1`P@N40(!OE
M`#"@XQ0P@N40(!OE`#"@XQ@P@N40(!OE`#"@XUPP@N4,T$OB`*B=Z`$C16>)
MJ\WO_MRZF'94,A#PX=+##<"@X0#8+>D$L$SB&-!-XA@`"^4<$`OE("`+Y1@P
M&^44()/E(#`;Y8,QH.$#,(+@$#`+Y1@P&^44()/E$#`;Y0,`4N$$``":&#`;
MY1@PD^4!((/B&#`;Y1@@@^48(!OE$#`;Y10P@N48,!OE&""3Y2`P&^6C/J#A
M`R""X!@P&^48((/E&#`;Y5PPD^4``%/C-0``"A@P&^5<,)/E0#!CXA0P"^44
M(!OE(#`;Y0,`4N$!``#:(#`;Y10P"^48,!OE'""#XA@P&^5<,)/E`S""X!0@
M&^4#`*#A'!`;Y;+R_^L@(!OE%#`;Y0(P8^`@,`OE%"`;Y1PP&^4",(/@'#`+
MY1@P&^5<()/E%#`;Y0,@@N`8,!OE7""#Y1@P&^5<,)/E0`!3XQP``!H8`!OE
M@/?_ZPT``.H8,!OE'#"#X@,`H.$<$!OE0""@XY?R_^L<,!OE0#"#XAPP"^4@
M,!OE0#!#XB`P"^48`!OE<??_ZR`P&^4_`%/C[O__RA@P&^4<,(/B("`;Y0,`
MH.$<$!OEAO+_ZQ@@&^4@,!OE7#""Y0S02^(`J)WH#<"@X0#8+>D$L$SB"-!-
MXA``"^44$`OE%``;Y5OW_^L4,!OE`#"3Y2,\H.'_,`/B$"`;Y0`PPN40,!OE
M`2"#XA0P&^4`,)/E(SB@X?\P`^(`,,+E$#`;Y0(@@^(4,!OE`#"3Y2,TH.'_
M,`/B`##"Y1`P&^4#((/B%#`;Y0`PD^7_,`/B`##"Y1`P&^4$((/B%#`;Y00P
MD^4C/*#A_S`#X@`PPN40,!OE!2"#XA0P&^4$,)/E(SB@X?\P`^(`,,+E$#`;
MY08@@^(4,!OE!#"3Y2,TH.'_,`/B`##"Y1`P&^4'((/B%#`;Y00PD^7_,`/B
M`##"Y1`P&^4(((/B%#`;Y0@PD^4C/*#A_S`#X@`PPN40,!OE"2"#XA0P&^4(
M,)/E(SB@X?\P`^(`,,+E$#`;Y0H@@^(4,!OE"#"3Y2,TH.'_,`/B`##"Y1`P
M&^4+((/B%#`;Y0@PD^7_,`/B`##"Y1`P&^4,((/B%#`;Y0PPD^4C/*#A_S`#
MX@`PPN40,!OE#2"#XA0P&^4,,)/E(SB@X?\P`^(`,,+E$#`;Y0X@@^(4,!OE
M##"3Y2,TH.'_,`/B`##"Y1`P&^4/((/B%#`;Y0PPD^7_,`/B`##"Y1`P&^40
M((/B%#`;Y1`PD^4C/*#A_S`#X@`PPN40,!OE$2"#XA0P&^40,)/E(SB@X?\P
M`^(`,,+E$#`;Y1(@@^(4,!OE$#"3Y2,TH.'_,`/B`##"Y1`P&^43((/B%#`;
MY1`PD^7_,`/B`##"Y0S02^(`J)WH#<"@X0#8+>D$L$SB&-!-XB``"^4D$`OE
M)#`;Y10PD^44,`OE)#`;Y1@PD^40,`OE%#`;Y:,QH.$_,`/B&#`+Y20P&^4<
M((/B&#`;Y0,@@N!_,.#C`##"Y1@P&^4!,(/B&#`+Y1@P&^4X`%/C$@``VB0P
M&^4<((/B&#`;Y0,@@N`8,!OE0#!CX@(`H.$`$*#C`R"@X9+Q_^LD`!OEJ_;_
MZR0P&^4<,(/B`P"@X0`0H.,X(*#CBO'_ZPD``.HD,!OE'""#XA@P&^4#((+@
M&#`;Y3@P8^("`*#A`!"@XP,@H.%_\?_K$#`;Y2,\H.'_,`/B)"`;Y50PPN40
M,!OE(SB@X?\P`^(D(!OE53#"Y1`P&^4C-*#A_S`#XB0@&^56,,+E$#`;Y?\P
M`^(D(!OE5S#"Y10P&^4C/*#A_S`#XB0@&^58,,+E%#`;Y2,XH.'_,`/B)"`;
MY5DPPN44,!OE(S2@X?\P`^(D(!OE6C#"Y10P&^7_,`/B)"`;Y5LPPN4@`!OE
M)!`;Y0W__^L,T$OB`*B=Z`W`H.$`V"WI!+!,X@C03>(`,*#C%#`+Y0`PH.,0
M,`OE6O'_ZP`PH.$#`*#AA/'_ZP`PH.$0,`OE$#`;Y0``4^,"```*$#`;Y0`P
MD^44,`OE%#`;Y0,`H.$,T$OB`*B=Z`W`H.$`V"WI!+!,X@C03>(0``OE``"@
MX]3Q_^L`,*#A`#"3Y0,`H.%,\?_K`#"@X0,`H.&=\?_K`#"@X1``&^4#$*#A
M$@<`ZP`PH.$``%/C)```&@``H./$\?_K`#"@X0`PD^4#`*#A//'_ZP`PH.$#
M`*#AC?'_ZP`PH.$0,)/E#SH#X@$)4^,-```*``"@X[;Q_^L`,*#A`#"3Y0,`
MH.$N\?_K`#"@X0,`H.%_\?_K`#"@X1`PD^4/.@/B"@I3XP@``!H0`!OE`A"@
MXR;Q_^L`,*#A``!3XP(``!H!,*#C%#`+Y0$``.H`,*#C%#`+Y10P&^4#`*#A
M#-!+X@"HG>@-P*#A$-@MZ02P3.(\T$WB0``+Y0`PH.,D,`OE`#"@XR`P"^4X
M,9_E/$!+X@/`H.$/`+SH#P"DZ`,`G.@#`(3H`#"@XQ@P"^4`,*#C'#`+Y34`
M`.HD`!OED?+_ZP`PH.$@,`OE(#`;Y0``4^,#```*(#`;Y0`PT^4``%/C`P``
M&B0`&^5`$!OEDO+_ZR,``.H@`!OE0!`;Y1WQ_^L`,*#A``!3XQT``!I``!OE
M`_'_ZP!`H.&L,)_E`#"3Y0,`H.'^\/_K`#"@X0-`A.`@`!OE^O#_ZP`PH.$#
M,(3@`C"#X@,`H.$E\?_K`#"@X1@P"^5P,)_E`,"3Y2`P&^4`,(WE&``;Y6`0
MG^5`(!OE##"@X6OQ_^LD`!OE&!`;Y6WR_^L<,!OE`3"#XAPP"^4<,!OE)R#@
MXP,QH.$4$$OB`S"!X`(P@^``,)/E)#`+Y20P&^4`,-/E``!3X[W__QH0T$OB
M$*B=Z#SU``!8T0$`"/0```W`H.$PV"WI!+!,XH'<3>(HT$WBN#>?Y1002^(#
M`('G`#"@XTPP"^4`,*#C2#`+Y0`PH.-$,`OEF#>?Y63`2^(/`)/H#P",Z(PW
MG^5\X$OB`\"@X0\`O.@/`*[H`P"<Z`,`CNAT-Y_EB,!+X@<`D^@'`(SH:#>?
MY4`P"^5D-Y_E/#`+Y0`PH.,X,`OE`#"@XS0P"^4`,*#C,#`+Y0`PH.,@,`OE
M0`>?Y2'R_^L`,*#A1#`+Y40P&^4``%/C"P``"D0P&^4`,-/E``!3XP<```I$
M`!OE;?__ZT0`&^7"\/_K`#"@X0(I2^(T,0+ELP$`Z@[__^L`,*#A-#`+Y30P
M&^4``%/C'P``&@`PH.-4,`OE#0``ZD@`&^4%\O_K`#"@X40P"^5$,!OE``!3
MXP,```I$`!OEK/#_ZP`PH.$T,`OE5#`;Y0$P@^)4,`OE-#`;Y0``4^,+```:
M5#`;Y7,@X.,#,:#A%`!+X@,P@.`",(/@`#"3Y4@P"^5(,!OE`##3Y0``4^/B
M__\:-#`;Y0``4^,"```:5#:?Y30P"^47``#J-#`;Y5`P"^40``#JB/#_ZP`P
MH.$`()/E4#`;Y0`PT^6#,*#A`S""X+`PT^$(,`/B``!3XP(``!I0,!OE7R"@
MXP`@P^50,!OE`3"#XE`P"^50,!OE`##3Y0``4^/J__\:`#"@XU0P"^42``#J
M2``;Y<?Q_^L`,*#A1#`+Y40P&^4``%/C"```"D0`&^77_O_K`#"@X0``4^,#
M```*1``;Y6GP_^L`,*#A3#`+Y50P&^4!,(/B5#`+Y4PP&^4``%/C"P``&E0P
M&^5G(.#C`S&@X1002^(#,('@`C"#X``PD^5(,`OE2#`;Y0`PT^4``%/CW?__
M&@`PH.-4,`OE"P``ZD0`&^6Y_O_K`#"@X0``4^,#```*1``;Y4OP_^L`,*#A
M3#`+Y50P&^4!,(/B5#`+Y4PP&^4``%/C"P``&E0P&^5/(.#C`S&@X10`2^(#
M,(#@`C"#X``PD^5$,`OE1#`;Y0`PT^4``%/CY/__&DP`&^4.\/_K`$"@X4``
M&^4+\/_K`#"@X0-`A.`T`!OE!_#_ZP`PH.$#0(3@/``;Y0/P_^L`,*#A`S"$
MX`$[@^(@,`OE(#`;Y0,`H.$L\/_K`#"@X3`P"^6(-)_E`,"3Y4`P&^4`,(WE
M-#`;Y00PC>4P`!OE<!2?Y4P@&^4,,*#A</#_ZS``&^5@%)_EC.__ZUP$G^5C
M\?_K`#"@X40P"^4@-)_E%!!+X@,PD><`0)/E1``;Y0GP_^L`,*#A!`"@X0,0
MH.'"\O_K`#"@X3@P"^4X,!OE``!3XP0``!KD,Y_E%"!+X@,PDN<`,)/E.#`+
MY97T_^L`,*#A``!3XZ4``!HX`!OE`!"@X]SO_^L`,*#A+#`+Y2PP&^4``%/C
MG0``"@(PH.,`,(WE+``;Y1$@X.,`,.#C[^__ZX$\2^(4,$/B+``;Y0,0H.$&
M(*#CH>__ZZ`SG^44`$OB`S#0YP``4^-$```:C#.?Y0$@H.,4$$OB`S"!X`(P
M@^``,-/E0P!3XSP``!IL,Y_E`B"@XQ0`2^(#,(#@`C"#X``PT^5!`%/C-```
M&DPSG^4#(*#C%!!+X@,P@>`",(/@`##3Y4,`4^,L```:+#.?Y00@H.,4`$OB
M`S"`X`(P@^``,-/E2`!3XR0``!H,,Y_E!2"@XQ002^(#,('@`C"#X``PT^5%
M`%/C'```&@(PH.,`,(WE+``;Y3D@X.,`,.#CMN__ZX$\2^(4,$/B+``;Y0,0
MH.$I(*#C:.__ZS``&^6![__K`""@X3`P&^4"((/@F#*?Y0#`D^6!3$OB%$!$
MXCPP&^4`,(WE`@"@X9`2G^4,(*#A!#"@X?3O_^N&``#J13]+X@,`H.%F_/_K
M!@``ZD4_2^*!+$OB%"!"X@,`H.$"$*#A*"`;Y8+\_^N!/$OB%#!#XBP`&^4#
M$*#A`BF@XT;O_^L`,*#A*#`+Y2@P&^4``%/C[?__RBP`&^5R[__K@3Q+XA0P
M0^(4,$/B12]+X@,`H.$"$*#A9_W_ZP`PH.,D,`OE$```ZB0P&^6#,*#AL2!+
MX@,@@N`D$!OEY#&?Y10`2^(#,(#@`3"#X``PT^4"`*#AT!&?Y0,@H.'#[__K
M)#`;Y0$P@^(D,`OE)#`;Y1,`4^/K___:`#"@XXDP2^4P`!OE..__ZP`@H.$P
M,!OE`B"#X'0QG^4`P)/EL4!+XCPP&^4`,(WE`@"@X7`1G^4,(*#A!#"@X:SO
M_^L^``#J`#"@XQPP"^4P`!OE)N__ZP`PH.$8,`OE4`&?Y5`1G^6G\/_K,``;
MY1_O_^L`(*#A,#`;Y0)`@^`0,9_E`%"3Y63O_^L`P*#A/#`;Y0`PC>4$`*#A
M'!&?Y04@H.$,,*#ADN__ZQD``.HP(!OE&#`;Y0,@@N``,*#C`##"Y3``&^4)
M[__K`""@X3`P&^4"0(/@N#"?Y0!0D^5.[__K`,"@X1PP&^4!,(/B'#`+Y1PP
M&^4`,(WE/#`;Y00PC>4$`*#AM!"?Y04@H.$,,*#A=^__ZS``&^5\$)_ED^[_
MZP`PH.$!`'/C!```&FWO_^L`,*#A`#"3Y1$`4^/:__\*1`"?Y3`0&^5N\/_K
M,``;Y;;]_^LP(!OE`AE+XC0A`>4""4OB-#$0Y0,`H.$4T$OB,*B=Z.1^__^X
M]0``D/4``&CU``#(]0``./4``.CS``#0]0``5-$!`-CU``#M`0``'/4```!_
M___D]0``['[___3U```L]```S/0``/SU```(]@``#<"@X1#8+>D$L$SBA-!-
MXI``"^4`,*#C'#`+Y9`P&^4``%/C4```"I`P&^4`,-/E``!3XTP```J0`!OE
M8^[_ZP`PH.$D,`OE)#`;Y0``4^-%```*.0``ZB`P&^43,(/B`P"@X0@1G^4G
M[__K`#"@X0``4^,Q```*(#`;Y1,P@^(#`*#A[!"?Y1_O_^L`,*#A``!3XRD`
M``J0`!OEHN[_ZP!`H.$@,!OE$S"#X@,`H.&=[O_K`#"@X0,PA.`",(/B&#`+
MY1@P&^4#`*#AQN[_ZP`PH.$<,`OE(#`;Y1,P@^(<`!OED!"?Y9`@&^4/[__K
MC#!+XAP`&^4#$*#A.P0`ZP`PH.$!`'/C!@``"GPP&^4/.@/B`0E3XP(``!H<
M`!OEMO__ZP$``.H<`!OE@>[_ZQP`&^5>[O_K`#"@XQPP"^4D`!OEU>[_ZP`P
MH.$@,`OE(#`;Y0``4^.^__\:)``;Y8_N_^N0`!OEI>[_ZQ#02^(0J)WH!/0`
M`!CV```<]@``#<"@X0#8+>D$L$SB$-!-XA@`"^48`!OE1/+_ZP`PH.$4,`OE
M%``;Y2#R_^L`,*#A$#`+Y1[S_^L`,*#A``!3XP\```H8,!OE``!3XPP```H8
M,!OE`##3Y0``4^,(```*$``;Y2`0G^5D[O_K`""@X1`P&^4#`%+A`0``&A@`
M&^5^___K#-!+X@"HG>C(]0``#<"@X1#8+>D$L$SB%-!-XA@0"^4``*#CJ^[_
MZP`PH.$`,)/E`P"@X2/N_^L`,*#A`P"@X=7M_^L`,*#A`#"3Y01`D^4``*#C
MG^[_ZP`PH.$`,)/E`P"@X1?N_^L`,*#A`P"@X>?M_^L`,*#A`##3Y?\P`^(8
M,,3E``"@XY+N_^L`,*#A`#"3Y0,`H.$*[O_K`#"@X0,`H.&\[?_K`#"@X0`P
MD^4$0)/E``"@XX;N_^L`,*#A`#"3Y0,`H.'^[?_K`#"@X0,`H.'1[?_K`#"@
MX0`PD^6P,=/A@SN@X:,[H.$#.*#A(SB@X;HQQ.$``*#C=>[_ZP`PH.$`,)/E
M`P"@X>WM_^L`,*#A`P"@X9_M_^L`,*#A`#"3Y01`D^4``*#C:>[_ZP`PH.$`
M,)/E`P"@X>'M_^L`,*#A`P"@X?@1G^4`(*#C2.[_ZP`PH.$<,(3E``"@XUSN
M_^L`,*#A`#"3Y0,`H.'4[?_K`#"@X0,`H.&&[?_K`#"@X0`PD^4$0)/E``"@
MXU#N_^L`,*#A`#"3Y0,`H.'([?_K`#"@X0,`H.&5[?_K`#"@X0`PD^4@,(3E
M``"@XT3N_^L`,*#A`#"3Y0,`H.&\[?_K`#"@X0,`H.%N[?_K`#"@X0`PD^4$
M,)/E(#`+Y0``H.,W[O_K`#"@X0`PD^4#`*#AK^W_ZP`PH.$#`*#A_>W_ZP`P
MH.$`,)/E``!3XPT```H``*#C*N[_ZP`PH.$`,)/E`P"@X:+M_^L`,*#A`P"@
MX?#M_^L`,*#A`#"3Y6PPD^4<,`OE`0``Z@`@H.,<(`OE'"`;Y2`P&^4D((/E
M``"@XQ?N_^L`,*#A`#"3Y0,`H.&/[?_K`#"@X0,`H.%![?_K`#"@X0`PD^4$
M()/E`#"@XR@P@N4``*#C">[_ZP`PH.$`,)/E`P"@X8'M_^L`,*#A`P"@X3/M
M_^L`,*#A`#"3Y00@D^4`,*#C+#""Y0``H./[[?_K`#"@X0`PD^4#`*#A<^W_
MZP`PH.$#`*#A)>W_ZP`PH.$`,)/E!$"3Y0``H./O[?_K`#"@X0`PD^4#`*#A
M9^W_ZP`PH.$#`*#AUNW_ZP`PH.$`,)/E,#"$Y1#02^(0J)WH./4```W`H.$`
MV"WI!+!,X@C03>(0$`OE``"@X]OM_^L`,*#A`#"3Y0,`H.%3[?_K`#"@X0,`
MH.$`$.#C1NW_ZP``H./1[?_K`#"@X0`PD^4#`*#A2>W_ZP`PH.$#`*#A#!"?
MY0`@H./@[?_K#-!+X@"HG>BDW@``#<"@X0#8+>D$L$SB.-!-XC`0"^4`,*#C
M&#`+Y0``H..\[?_K`#"@X0`PD^4#`*#A-.W_ZP`PH.$#`*#A-^W_ZP`@H.$!
M,*#C`##"Y3P&G^6][O_K`#"@X10P"^44,!OE``!3XP@```H4,!OE`##3Y3$`
M4^,$```:%#`;Y0$P@^(`,-/E``!3XP````J+\?_K``"@XY_M_^L`,*#A`#"3
MY0,`H.$7[?_K`#"@X0,`H.'<%9_E`2"@XPLPH./S[/_K`#"@X2PP"^4L,!OE
M``!3XVL```HL,!OE##"3Y1@PD^4H,`OE`3"@XQPP"^5"``#J``"@XX?M_^L`
M,*#A`#"3Y0,`H.'_[/_K`#"@X0,@H.$<,!OE`3!#X@(`H.$H$!OE`R"@X0`P
MH.,@[?_K`#"@X20P"^4D,!OE``!3XS,```I0-9_E`""3Y1PP&^4#,:#A`S""
MX``PD^5$,`OE)#`;Y0`PD^4(,)/E`3L#X@``4^,$```*)#`;Y0`PD^4,,)/E
M0#`+Y1```.H``*#C8>W_ZP`PH.$`,)/E`P"@X=GL_^L`,*#A`R"@X20P&^4`
M,)/E`@"@X0,0H.$`(*#C`C"@XV_M_^L`,*#A0#`+Y40`&^5`$!OE6^W_ZP`P
MH.$``%/C"@``&A@P&^4!,(/B&#`+Y1PP&^4!,(/B'#`+Y9@TG^4`()/E'#`;
MY0(`4^&W__^ZA#2?Y0`PD^4!($/B&#`;Y0,`4N$6```:`3"@XQPP"^4.``#J
M``"@XS;M_^L`,*#A`#"3Y0,`H.&N[/_K`#"@X0,`H.$H$!OEB>S_ZP`PH.$@
M,`OE'#`;Y0$P@^(<,`OE)#2?Y0`@D^4<,!OE`@!3X>O__[H``*#C(NW_ZP`P
MH.$`,)/E`P"@X9KL_^L`,*#A`P"@X?03G^4!(*#C!3"@XW;L_^L`,*#A+#`+
MY2PP&^4``%/C(P``"@``H.,1[?_K`#"@X0`PD^4#`*#AB>S_ZP`PH.$#(*#A
M+#`;Y0PPD^4`,)/E`@"@X0,0H.&@(Y_E:.S_ZRPP&^4,,)/E`#"3Y0@PD^4!
M-0/B``!3XPT```H``*#C^^S_ZP`PH.$`,)/E`P"@X7/L_^L`,*#A`R"@X2PP
M&^4,,)/E`#"3Y0(`H.$#$*#AK>S_ZP``H./M[/_K`#"@X0`PD^4#`*#A9>S_
MZP`PH.$#`*#A*!.?Y0$@H.,%,*#C0>S_ZP`PH.$L,`OE+#`;Y0``4^,J```*
M`#"@XQ`P"^4``Y_EY^W_ZP`PH.$0,`OE$#`;Y0``4^,/```*``"@X]/L_^L`
M,*#A`#"3Y0,`H.%+[/_K`#"@X0,@H.$L,!OE##"3Y0`PD^4"`*#A`Q"@X1`@
M&^4J[/_K$0``Z@``H./#[/_K`#"@X0`PD^4#`*#A.^S_ZP`PH.$#$*#A+#`;
MY0PPD^4`()/E9#*?Y0`PD^4`,)/E`0"@X0(0H.$#(*#A%.W_ZP``H..Q[/_K
M`#"@X0`PD^4#`*#A*>S_ZP`PH.$#`*#A+.S_ZP`@H.$`,*#C`##"Y0``H..E
M[/_K`#"@X0`PD^4#`*#A'>S_ZP`PH.$#`*#AI^S_ZP`@H.$`,*#C`#""Y0`"
MG^6F[?_K`""@X?@QG^4`((/E\#&?Y0`PD^4``%/C5```&L0QG^4`,)/E`P"@
MX4[[_^L`(*#AS#&?Y0`@@^4L,!OE##"3Y0`PD^4(,)/E`3L#X@``4^,%```*
M+#`;Y0PPD^4`,)/E##"3Y3PP"^41``#J``"@XWSL_^L`,*#A`#"3Y0,`H.'T
MZ__K`#"@X0,@H.$L,!OE##"3Y0`PD^4"`*#A`Q"@X0`@H.,",*#CB>S_ZP`P
MH.$\,`OE+#&?Y0`PD^4\`!OE`Q"@X<[K_^L`,*#A'#`+Y1`QG^4`,)/E`#"3
MY3@P"^4L,!OE##"3Y0`PD^4(,)/E`3L#X@``4^,%```*+#`;Y0PPD^4`,)/E
M##"3Y30P"^41``#J``"@XU+L_^L`,*#A`#"3Y0,`H.'*Z__K`#"@X0,@H.$L
M,!OE##"3Y0`PD^4"`*#A`Q"@X0`@H.,",*#C7^S_ZP`PH.$T,`OEI`"?Y3@0
M&^4T(!OE'#`;Y1;L_^N,,)_E`#"3Y0,`H.&($)_E;.O_ZP`PH.$<,`OE'#`;
MY0``4^,/```*'#`;Y1$`4^,,```*'#`;Y0$`<^,)```*,#"?Y0`PD^4`()/E
M0#"?Y0`PD^5$`)_E`A"@X0,@H.$<,!OE_.O_ZPS02^(`J)WH$/0``"3V``"0
MX0$`C.$!`"SV```P]@``./8``/3S``#H\P``B.$!`#SV``#M`0``;/8```W`
MH.$`V"WI!+!,X@C03>(``*#C#NS_ZP`PH.$`,)/E`P"@X8;K_^L`,*#A`P"@
MX5'L_^L``*#C!>S_ZP`PH.$`,)/E`P"@X7WK_^L`,*#A`R"@X20PG^4`,(WE
M`#"@XP0PC>4"`*#A%!"?Y10@G^4(,)_EA.O_ZPS02^(`J)WH./4``+SV``!8
MX@``#<"@X1#8+>D$L$SB+-!-XB``"^4D$`OE*"`+Y2`P2^(D($OB*,!+X@,`
MH.$"$*#A#""@X>#K_^O``Y_EP!.?Y;PCG^7[``#K``"@XTKK_^L`,*#A`##3
MY0``4^,9```:0NO_ZP`@H.&8,Y_E`""#Y9`SG^4`,)/E``!3XP$``!H!`*#C
MWNO_ZW@SG^4`,)/E`P"@X5SK_^L``*#CR>O_ZP`PH.$`,)/E`P"@X4'K_^L`
M,*#A`P"@X9[K_^L`(*#A`#"@XP`PPN4``*#CO>O_ZP`PH.$`,)/E`P"@X37K
M_^L`,*#A`P"@X;GK_^L`,*#A`R"@X0`PTN4",(/C_S`#X@`PPN4``*#CKNO_
MZP`PH.$`,)/E`P"@X2;K_^L`,*#A`P"@X:KK_^L`,*#A`R"@X0`PTN4!,(/C
M_S`#X@`PPN4@,!OE!3"#X@,`H.&8`0#K`#"@X0%`H.$#`*#A!!"@X0`@H.,`
M,*#CY@``ZP`PH.$!0*#A`Q"@X00@H.$`,*#C-#!+Y0$`H.$"$*#AF2^/X@P`
MDN@+`@#K`#"@X0``4^,!```*`3"@XS0P2^4T(%OE_S`"X@$P(^+_,`/B``!3
MXP$``!I``I_E5^O_ZR`P&^4%,(/B`S&@X0,`H.%;Z__K`#"@X0,@H.$@,I_E
M`""#Y1@RG^4`()/E)#`;Y0`PD^4`,(+E!#*?Y0`PD^4$((/B_#&?Y0`P@N7P
M,9_E`#"3Y0@@@^+L,9_E`#""Y>@AG^4#,*#C`#""Y=`QG^4`()/EU#&?Y0`P
MD^4#,:#A`R""X,@QG^4`,(+EO#&?Y0`PD^4!((/BL#&?Y0`@@^4!,*#C&#`+
MY1(``.J0,9_E`!"3Y90QG^4`()/E&#`;Y0,P@N`!,&/B`S&@X0`P8^(#$('@
M)"`;Y1@P&^4#,:#A`S""X``PD^4`,('E&#`;Y0$P@^(8,`OE("`;Y1@P&^4"
M`%/AZ/__NC0QG^4`$)/E("`;Y30QG^4`,)/E`S""X`$P8^(#,:#A`#!CX@,@
M@>``,*#C`#""Y?PPG^4`$)/E("`;Y00QG^4`,)/E`S""X`$@0^+H,)_E`,"3
MY0`PH.,`,(WE`0"@X>@0G^4,,*#A8>K_ZP`PH.$<,`OE'#`;Y0``4^,%```:
MK#"?Y0`PD^4#`*#A<.K_ZP`PH.$<,`OEE#"?Y0`PD^4#`*#AP>K_ZZ0`G^4=
M[/_K`#"@X0``4^,0```:E#"?Y0`PD^4``%/C!```&H@`G^44[/_K`""@X7@P
MG^4`((/E<#"?Y0`PD^4``%/C`P``"F`PG^4`,)/E`P"@X27\_^LL,)_E`#"3
MY0,`H.$OZO_K?.K_ZQPP&^4#`*#A$-!+XA"HG>@``(#____/09R7``"(E@``
MA.$!`&S1`0"0X0$`U/8``.3V``",X0$`V/8``!SI```@]```B.$!`.CS````
M`*#A'#"?Y1S`G^4#,(_@!$`MY0Q`D^`$,*`!##"3%Q``O>BPZO_J$.(``%`!
M```>_R_A\$4MZ0303>(!@*#A`G"@X0"@H.'XZ?_K2!"?Y4@PG^5(()_E`S!A
MX`(@C^!#4;#A`2""X`D```H"8*#A`$"@XPH`H.$($*#A!R"@X0_@H.$$\9;G
M`4"$X@4`5.'W__\Z!-"-XO"%O>CD_O__Z/[__\#A```!(*#A`!"@X0,`H.-N
MZO_J`2"@X0`0H.$#`*#CG>K_Z@(1(>(```#J`C$CXC!`+>F!0*#A@U"@X04`
M-.$"`#`!`,"4$0+`E1'$RO`1Q<KP$7D```JD2J#AI5ITX`!09;(&``#:!4"$
MX`(@(.`#,"'@```BX`$0(^`"("#@`S`AX#8`5>,P@+V(`@$1XP$6H.$!QJ#C
M(1:,X0$```H``'#B`!#AX@(!$^,#-J#A(S:,X0$```H`('+B`##CX@4`-.%7
M```*`4!$XB#@=>(%``"Z$LZ@X3(%D.``$*'B$PZ0X%,5L>`&``#J(%!%XB#@
MCN(!`%+C$\Z@X0+`C"-3!9#@PQ^QX`)1`>("``!:`,!\X@``\.(`$.'B`091
MXPX``#H"!E'C!@``.J$0L.%@`+#A;,"@X0%`A.*$*J#A`05RXU4``"H"`5SC
MH,"P`0``L.($&J'@!1"!X3"`O>B,P+#A``"PX`$0H>`!!A'C`4!$XO/__QH`
M`#'C`!"@`0``H`,1/V_A(#"#`@LP0^(@(%/B!P``J@P@DN($``#:%,""X@P@
M8N(1#*#A,1*@X00``.H4((+B(,!BTA$2H.$P'('1$`*@T0-`5.`$&H&@!1"!
MH3"`O:@$0.#A'T!4X@T``*H,0)3B!0``RA1`A.(@(&3B,`2@X1$"@.$Q%(7A
M,("]Z`Q`9.(@(&3B,`*@X1$$@.$%$*#A,("]Z#$$H.$%$*#A,("]Z```-.,!
M-B/B`18A`@%`A`(!4$42H?__ZL3*\.'%RO`1&```"@4`-.$"`#`!`P``"@#`
ME.$#$*`!`@"@`3"`O>@#`#'A`!"@$P``H!,P@+T8I,JPX0,``!J``+#A`1"Q
MX`(1@2,P@+WH`464X@$6@3(P@+TX`E$!XG\4A>,/%H'C``"@XS"`O>C$RO#A
M`Q"@$0(`H!'%RO`!`3"@$0`@H!$!1I#A`U:2`0,`,0$"%X$3,("]Z```,.,`
M$*`#'O\O`3!`+>D!2Z#C,D"$X@!0H.,`$*#CG?__Z@``,.,`$*`#'O\O`3!`
M+>D!2Z#C,D"$X@)1$.(``&!"`!"@XY/__^J`(+#APA&@X6$0H.$"#J#A_S02
M$O\$,Q,.$R$2'O\O$0``,N/_!#,3'O\O`3!`+>D.3:#C`E$!X@(1P>.#___J
M`2"0X1[_+P$P0"WI`%"@XP8``.H!()#A'O\O`3!`+>D"41'B`0``6@``<.(`
M$.'B`4N@XS)`A.(AR[#A7/__"@,@H..LP;#A`R""$JS!L.$#(((2K"&"X"`P
M8N(0PZ#A,`*@X1$#@.$Q$J#A`D"$X$___^H`P.#C`@``Z@'`H.,```#J`<"@
MXP3`#>6!P*#AS,KPX8/`H.',RO`1#0``"H'`D.&#P)(!`P`Q$0(`,`$``*`#
M'O\O`0``<.,#`#'A`P!140(`4`'##Z`APP_@,0$`@.,>_R_A@<"@X<S*\.$!
M```:`<:0X00``!J#P*#AS,KPX>G__QH#QI+AY___"@0`'>4>_R_A`,"@X0(`
MH.$,(*#A`<"@X0,0H.$,,*#A____Z@%`+>G5___K``!0XP``<$,!@+WH".`M
MY?C__^L!`*`#``"@$PCPG>0(X"WE\___ZP$`H#,``*`C"/"=Y`C@+>7N___K
M`0"@DP``H(,(\)WD".`MY>+__^L!`*"3``"@@PCPG>0(X"WEW?__ZP$`H#,`
M`*`C"/"=Y`3@+>4$T$WB!-"-X@"`O>@!``(`<&5R;'AS:2YC````1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`"]P<F]C+W-E;&8O97AE```O````.@``
M`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!344`````
M+@```"5S)7,E<P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#
M3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]!4D=#`````%!!
M4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$
M25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@````!005)?0TQ%04X]```Q````7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("``````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%2
M65]0051(`````%!!5$@`````1%E,1%],24)205)97U!!5$@`````````]/0`
M``3U```,]0``'/4``"3U```X]0``55-%4@````!54T523D%-10````!4]0``
M7/4``#CU``!435!$25(``%1%35!$25(`5$5-4`````!435``D/0``'3U``!\
M]0``A/4``(SU```X]0``0SI<5$5-4``O=&UP`````*CU``"P]0``!/0``#CU
M``!P87(M`````%-94U1%30``)7,E<R5S)7,`````)7-C86-H92TE<R5S````
M`"4P,G@`````)7-T96UP+25U)7,`)7-T96UP+25U+25U)7,``"XN```E<R\E
M<P```$%21U8`````&````'!E<FP`````,````"5S.B!E>&5C=71I;VX@;V8@
M)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@
M86)O<G1I;F<@=VET:"`E:2X*````26YT97)N86QS.CI005(Z.D)/3U0`````
M+64``"TM``!P87(N<&P``",A+W5S<B]B:6XO<&5R;`H*979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P[
M"@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@
M870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3D*
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`[
M"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE
M.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@
M(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B
M96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@
M(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R
M7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H
M:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T
M;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA
M=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@
M(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N
M(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M
M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI
M<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN
M9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@
M(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%
M(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^
M("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*
M"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I
M"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE
M;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T
M;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I
M"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"
M14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET
M7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6
M>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%2
M1U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@
M)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6
M*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*
M("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX
M("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@
M*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I
M;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[
M>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L
M(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@
M("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN
M(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@
M9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@
M("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@
M("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@
M("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D
M8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B
M=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@
M("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D
M('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D
M14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@
M)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@
M("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL
M;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@
M/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@
M("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@
M("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@
M("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@
M("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@
M("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E
M96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M
M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@
M("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E
M='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)
M3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@
M("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@
M<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@
M(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@
M("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M
M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S
M="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA
M;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L
M97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R
M97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I
M=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C
M97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[
M4$%27T1%0E5'?3L*"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O
M;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@
M("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@
M('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@
M("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@;7D@0&%D9%]T;U]I;F,[
M"B`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`D05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("!I9B`H
M)#$@97$@)TDG*2!["B`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R
M.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@
M("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G02<I('L*("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@
M("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@
M("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@(&]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@
M;&]G.B`D(2(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I
M('L*("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("!]"@H@
M("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PH@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("!R
M97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@(&5X:70["B`@
M("`@("`@?0H@("`@?0H*("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*
M"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*
M("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I
M;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H*("`@
M(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I
M9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@
M)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@
M)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R![
M"B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP
M87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@
M("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@
M("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F
M:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@
M)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D
M(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B
M)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP
M,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@
M("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@
M;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN
M960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@
M7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@
M(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA
M<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@
M*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@
M+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@
M*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@
M('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@
M("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@
M(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@
M("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@
M("!I;FET7VEN8R@I.PH@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@
M("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@
M/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A
M+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L
M92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@
M("`@("`@:68@*"1#;VYF:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]
M9R!F;W(@0&EN8R!]"@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\
M*"XK*20O(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@
M("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY
M("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@
M("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@
M("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@
M("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@
M("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T
M("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@
M("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@
M("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@
M("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI
M('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D
M9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@
M("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@
M("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$
M;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O
M;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T
M<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@
M("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@
M("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@
M("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@
M("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I
M8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@
M1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R
M<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C
M='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@
M)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB
M*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@
M(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE
M(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@
M(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ
M3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@
M07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@
M(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@
M("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@
M("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@
M("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@
M("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@
M("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@
M?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@
M("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E
M<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14
M;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF
M('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI
M9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H
M)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64[
M"B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E
M;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E
M<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*
M("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@
M<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U
M:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#
M87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I
M<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E
M($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER
M92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E
M($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U
M:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@979A;"![(')E<75I
M<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*?0H*(R!4:&4@0R!V97)S:6]N
M(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*<W5B
M(%]S971?<&%R7W1E;7`@>PH@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@
M/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R
M;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W
M;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]
M("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E
M;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@
M)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@
M("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@
M("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F
M(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B
M=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@
M("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@
M:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#
M3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U
M.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*
M("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P
M87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@
M("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L
M<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR
M("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N
M86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D
M9F@L("1F:6QE;F%M92D["GT*"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF
M("@D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@
M("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A
M;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@
M("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US
M("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N
M9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I
M9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*
M"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@
M("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@
M("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@
M("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@
M>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W
M;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H
M;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET
M7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%2
M1U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@
M("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*
M"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@
M("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E
M>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V
M86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB
M*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@
M<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P
M<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@
M<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q
M=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@
M<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP
M="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@
M(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@
M('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN
M92`Y.3,*"E]?14Y$7U\*`````*1+_W\!````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!@
MF@``1)H````````!`````0````$```"_`@```0```,H"```!````U`(```$`
M```C`P```0```#P$```,````#)8```T```"$\P``&0```.3.`0`;````!```
M`!H```#HS@$`'`````0````$````B($```4```!TC```!@```/2$```*````
MV`4```L````0````%0`````````#`````-`!``(```!X`@``%````!$````7
M````E),``!$```!\DP``$@```!@````3````"````/[__V\\DP``____;P(`
M``#P__]O3)(`````````````````````````````````````````````````
M`````````````````/#.`0```````````""6```@E@``()8``""6```@E@``
M()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6```@
ME@``()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6
M```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8`
M`""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``
M()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6```@
ME@``()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6
M```@E@``()8``""6```@E@``()8``""6``````````````````#0\P``U/,`
M`/_____<]@``7%<```!'0T,Z("A58G5N='4@-"XS+C,M-75B=6YT=30I(#0N
M,RXS``!'0T,Z("A58G5N='4@-"XS+C,M-75B=6YT=30I(#0N,RXS``!'0T,Z
M("A58G5N='4@-"XS+C,M-75B=6YT=30I(#0N,RXS``!'0T,Z("A58G5N='4@
M-"XS+C,M-75B=6YT=30I(#0N,RXS``!'0T,Z("A58G5N='4@-"XS+C,M-75B
M=6YT=30I(#0N,RXS``!'0T,Z("A58G5N='4@-"XS+C,M-75B=6YT=30I(#0N
M,RXS``!'0T,Z("A58G5N='4@-"XS+C,M-75B=6YT=30I(#0N,RXS``!'0T,Z
M("A58G5N='4@-"XS+C,M-75B=6YT=30I(#0N,RXS``!'0T,Z("A58G5N='4@
M-"XS+C,M-75B=6YT=30I(#0N,RXS``!'0T,Z("A58G5N='4@-"XS+C,M-75B
M=6YT=30I(#0N,RXS``!'0T,Z("A58G5N='4@-"XS+C,M-75B=6YT=30I(#0N
M,RXS`$$G````865A8FD``1T````%-50`!@0(`0D!$@04`14!%P,8`1D!&@(`
M+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN
M`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED
M>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S
M````````````````````````````````````````````````````````"P``
M``$````"````5($``%0!```3```````````````!`````````!,````'````
M`@```&B!``!H`0``(```````````````!``````````A````!0````(```"(
M@0``B`$``&P#```$``````````0````$````)P````L````"````](0``/0$
M``"`!P``!0````$````$````$````"\````#`````@```'2,``!T#```V`4`
M`````````````0`````````W````____;P(```!,D@``3!(``/`````$````
M``````(````"````1````/[__V\"````/),``#P3``!`````!0````(````$
M`````````%,````)`````@```'R3``!\$P``&`````0`````````!`````@`
M``!<````"0````(```"4DP``E!,``'@"```$````"P````0````(````90``
M``$````&````#)8```P6```4```````````````$`````````&`````!````
M!@```""6```@%@``R`,`````````````!`````0```!K`````0````8```#H
MF0``Z!D``)Q9``````````````@`````````<0````$````&````A/,``(1S
M```0```````````````$`````````'<````!`````@```)3S``"4<P``L%H`
M````````````!`````````!_`````0``<((```!$3@$`1,X```@````,````
M``````0`````````B@````$````"````3$X!`$S.```$```````````````$
M`````````)0````.`````P```.3.`0#DS@``!```````````````!```````
M``"@````#P````,```#HS@$`Z,X```0```````````````0`````````K```
M``$````#````[,X!`.S.```$```````````````$`````````+$````&````
M`P```/#.`0#PS@``$`$```4`````````!`````@```"Z`````0````,`````
MT`$``-```$P!``````````````0````$````OP````$````#````3-$!`$S1
M```<```````````````$`````````,4````(`````P```&C1`0!HT0``+!``
M````````````"`````````#*`````0``````````````:-$``(P!````````
M``````$`````````TP````,``'```````````/32```H```````````````!
M``````````$````#```````````````<TP``XP```````````````0``````
M```!````()8```````````L`!````#"6```````````+``$````TE@``````
,````"P``)&$`)&0`
